==> coin2_2.3.0.orig.tar.gz: Coin-2.3.0/include/Inventor/C/threads/fifop.h <==
#ifndef CC_FIFOP_H
#define CC_FIFOP_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2004 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Teknobyen, Abels Gate 5, 7030 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#ifndef COIN_INTERNAL
#error this is a private header file
#endif /* !COIN_INTERNAL */

#include <Inventor/C/threads/common.h>
#include <Inventor/C/threads/mutexp.h>
#include <Inventor/C/threads/condvarp.h>

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif /* HAVE_CONFIG_H */

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/* ********************************************************************** */

typedef struct cc_fifo_item cc_fifo_item;

struct cc_fifo_item {
  cc_fifo_item * next;
  void *         item;
  uint32_t       type;
};

struct cc_fifo {
  cc_mutex       access;

  cc_fifo_item * head;
  cc_fifo_item * tail;
  cc_fifo_item * free;

  unsigned int   elements;

  cc_condvar     sleep;
};

/* ********************************************************************** */

void cc_fifo_struct_init(cc_fifo * fifo);
void cc_fifo_struct_clean(cc_fifo * fifo);

/* ********************************************************************** */

#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

#endif /* ! CC_FIFOP_H */

==> coin2_2.4.4.orig.tar.gz: Coin-2.4.4/include/Inventor/C/threads/fifop.h <==
#ifndef CC_FIFOP_H
#define CC_FIFOP_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#ifndef COIN_INTERNAL
#error this is a private header file
#endif /* !COIN_INTERNAL */

#include <Inventor/C/threads/common.h>
#include <Inventor/C/threads/mutexp.h>
#include <Inventor/C/threads/condvarp.h>

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif /* HAVE_CONFIG_H */

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/* ********************************************************************** */

typedef struct cc_fifo_item cc_fifo_item;

struct cc_fifo_item {
  cc_fifo_item * next;
  void *         item;
  uint32_t       type;
};

struct cc_fifo {
  cc_mutex       access;

  cc_fifo_item * head;
  cc_fifo_item * tail;
  cc_fifo_item * free;

  unsigned int   elements;

  cc_condvar     sleep;
};

/* ********************************************************************** */

void cc_fifo_struct_init(cc_fifo * fifo);
void cc_fifo_struct_clean(cc_fifo * fifo);

/* ********************************************************************** */

#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

#endif /* ! CC_FIFOP_H */
